//
// VPPIFACE.H
// ==========
//
// The DLL-Interface for the "Virtual Print Engine Professional Edition".
//
// To be used by the calling applications.
//
// Copyright  1999 - 2008 IDEAL Software GmbH, Neuss, Germany. All rights reserved.
//



#ifndef _MODULE_VPPIFACE
#define _MODULE_VPPIFACE


// ========================================================================
//                                  DEFINES
// ========================================================================

// $ +n Type JpegExportOptions (PICEXP_JPEG_)
// $ +av Type JpegExportOptions
enum JpegExportOptions
{
	PICEXP_JPEG_DEFAULT			= 0x0000,		// Saves with good quality (75:1)
	PICEXP_JPEG_HI_QUALITY		= 0x0080,		// Saves with superb quality (100:1)
	PICEXP_JPEG_GOOD_QUALITY	= 0x0100,		// Saves with good quality (75:1)
	PICEXP_JPEG_MID_QUALITY		= 0x0200,		// Saves with normal quality (50:1)
	PICEXP_JPEG_LO_QUALITY		= 0x0400,		// Saves with average quality (25:1)
	PICEXP_JPEG_BAD_QUALITY		= 0x0800,		// Saves with bad quality (10:1)
	PICEXP_JPEG_PROGRESSIVE		= 0x2000,		// if set, JPG files are written progressive (interlaced)
};


// $ +n Type TiffExportOptions (PICEXP_TIFF_)
// $ +av Type TiffExportOptions
enum TiffExportOptions
{
	PICEXP_TIFF_DEFAULT			= 0x0000,		// Save using CCITTFAX4 compression for 1-bit bitmaps and LZW compression for any other bitmaps
	PICEXP_TIFF_PACKBITS        = 0x0100,		// save using PACKBITS compression
	PICEXP_TIFF_DEFLATE         = 0x0200,		// save using DEFLATE compression (a.k.a. ZLIB compression)
	PICEXP_TIFF_ADOBE_DEFLATE   = 0x0400,		// save using ADOBE DEFLATE compression
	PICEXP_TIFF_NONE            = 0x0800,		// save without any compression
	PICEXP_TIFF_CCITTFAX3       = 0x1000,		// save using CCITT Group 3 fax encoding
	PICEXP_TIFF_CCITTFAX4       = 0x2000,		// save using CCITT Group 4 fax encoding
	PICEXP_TIFF_LZW             = 0x4000,		// save using LZW compression
	PICEXP_TIFF_JPEG            = 0x8000,		// save using JPEG compression (8-bit greyscale and 24-bit only. Default to LZW for other bitdepths.)
	PICEXP_TIFF_APPEND			= 0x40000000,	// append file to multi-page TIFF
};


// $ +n Type GifExportOptions (PICEXP_GIF_)
// $ +av Type GifExportOptions
enum GifExportOptions
{
	PICEXP_GIF_DEFAULT			= 0x0000,		// nothing special
	PICEXP_GIF_APPEND			= 0x40000000,	// append file to multi-page GIF
};


// $ +n Type BmpExportOptions (PICEXP_BMP_)
// $ +av Type BmpExportOptions
enum BmpExportOptions
{
	PICEXP_BMP_DEFAULT			= 0x00,			// save without any compression
	PICEXP_BMP_RLE				= 0x01,			// save RLE compressed
};


// $ +n Type PnmExportOptions (PICEXP_PNM_)
// $ +av Type PnmExportOptions
enum PnmExportOptions
{
	PICEXP_PNM_DEFAULT			= 0x00,			// PBM, PGM, PPM files are written RAW
	PICEXP_PNM_ASCII			= 0x01,			// PBM, PGM, PPM files are written ASCII
};


// $ +av skip

// Options for VpeSetPictureExportColorDepth():
// ============================================
// $ +n enum PictureExportColorDepth (PICEXP_) {
#define PICEXP_COLOR_MONO       1
#define PICEXP_COLOR_16         4
#define PICEXP_COLOR_256        8       // default
#define PICEXP_COLOR_HI         16
#define PICEXP_COLOR_TRUE       24
// $ }


// Options for VpeSetPictureExportDither():
// ========================================
// $ +n enum PictureExportDither (PICEXP_) {
#define PICEXP_DITHER_NONE      0       // default
#define PICEXP_DITHER_MONO      1
#define PICEXP_DITHER_256       3
#define PICEXP_DITHER_256_WU    4
// $ }


// Chart Types:
// ============
// $ +n enum ChartType (VCHART_) {
#define VCHART_POINT                    0
#define VCHART_LINE                     1
#define VCHART_BAR                      2
#define VCHART_STACKED_BAR_ABSOLUTE     3
#define VCHART_STACKED_BAR_PERCENT      4
// $ +n subst Bar3D
#define VCHART_3D_BAR                   5
// $ +n subst StackedBar3DAbsolute
#define VCHART_3D_STACKED_BAR_ABSOLUTE  6
// $ +n subst StackedBar3DPercent
#define VCHART_3D_STACKED_BAR_PERCENT   7
#define VCHART_PIE                      8
// $ +n subst Pie3D
#define VCHART_3D_PIE                   9
#define VCHART_AREA_ABSOLUTE           10
#define VCHART_AREA_PERCENT            11
// $ }


// Symbol Types (used in Point-Chart):
// ==================================
// $ +n enum ChartSymbol (VCHART_SYMBOL_) {
#define VCHART_SYMBOL_NONE           -1
#define VCHART_SYMBOL_SQUARE          0
#define VCHART_SYMBOL_TRIANGLE        1
#define VCHART_SYMBOL_CIRCLE          2
#define VCHART_SYMBOL_CROSS           3
#define VCHART_SYMBOL_X               4
#define VCHART_SYMBOL_POINT           5
// $ }


// Legend Positions:
// =================
// $ +n enum ChartLegendPosition (VCHART_LEGENDPOS_) {
#define VCHART_LEGENDPOS_NONE           -1
#define VCHART_LEGENDPOS_RIGHT           0
#define VCHART_LEGENDPOS_RIGHT_TOP       1
#define VCHART_LEGENDPOS_RIGHT_BOTTOM    2
#define VCHART_LEGENDPOS_LEFT            3
#define VCHART_LEGENDPOS_LEFT_TOP        4
#define VCHART_LEGENDPOS_LEFT_BOTTOM     5
#define VCHART_LEGENDPOS_TOP             6
#define VCHART_LEGENDPOS_BOTTOM          7
// $ }


// Label States:
// =============
// $ +n enum ChartLabelState (VCHART_LABEL_) {
#define VCHART_LABEL_NONE   -1          // No labels are drawn
#define VCHART_LABEL_USER    0          // User defined labels are drawn
#define VCHART_LABEL_AUTO    1          // Labeling is done automatically
// $ }


// Pie Label Types:
// ================
// $ +n enum ChartPieLabelType (VCHART_PIE_LABEL_) {
#define VCHART_PIE_LABEL_NONE        0 // no labels are drawn
#define VCHART_PIE_LABEL_PERCENTAGE  1 // the percentage values are drawn
#define VCHART_PIE_LABEL_LEGEND      2 // the legend texts are used for the labels
#define VCHART_PIE_LABEL_XLABELS     3 // the user-defined x-labels are used
// $ }


// Grid Types:
// ===========
// $ +n enum ChartGridType (VCHART_GRID_) {
#define VCHART_GRID_NONE         -1     // No Grid is drawn
#define VCHART_GRID_BOTH_AXIS     0     // Grid is drawn for both axis
#define VCHART_GRID_X_AXIS        1     // Grid is only drawn for the x-axis
#define VCHART_GRID_Y_AXIS        2     // Grid is only drawn for the y-axis
// $ }

// $ +av endskip


// 2D-Barcode alignment within specified rectangle (valid for all 2D-barcode types)
// $ +n Type Bar2DAlignment (VBAR2D_ALIGN_)
// $ +av Type Bar2DAlignment
enum
{ 
	VBAR2D_ALIGN_CENTER   = 0,    // horizontally and vertically centered
	VBAR2D_ALIGN_CENTER_H = 0,
	VBAR2D_ALIGN_LEFT     = 1,
	VBAR2D_ALIGN_RIGHT    = 2, 
	VBAR2D_ALIGN_CENTER_V = 0,
	VBAR2D_ALIGN_TOP      = 4,
	VBAR2D_ALIGN_BOTTOM   = 8,
};


// Encoding Format ID for DataMatrix symbologies
// Note: For ECC200 this is the start-up code page, while for ECC000 - ECC140 the selected format covers
//       the entire message.
// $ +n Type DataMatrixEncodingFormat (VBAR2D_DATA_MATRIX_ENC_)
// $ +av Type DataMatrixEncodingFormat
enum
{
	VBAR2D_DATA_MATRIX_ENC_BASE11	= 1,	// numeric data, 3.5 bits per digit
	VBAR2D_DATA_MATRIX_ENC_BASE27,			// upper case alphabetic, 4.8 bits per character
	VBAR2D_DATA_MATRIX_ENC_BASE41,			// upper case alphanumeric and punctuation, 5.5 bits per character
	VBAR2D_DATA_MATRIX_ENC_BASE37,			// upper case alphanumeric, 5.25 bits per character
	VBAR2D_DATA_MATRIX_ENC_ASCII,			// 128 ASCII set, 7 bits per character
	VBAR2D_DATA_MATRIX_ENC_BINARY,			// 8-bit Byte, 8 bits per character
};


// Error checking and correction types for DataMatrix symbologies
// $ +n Type DataMatrixEccType (VBAR2D_DATA_MATRIX_)
// $ +av Type DataMatrixEccType
enum
{
	VBAR2D_DATA_MATRIX_ECC000,
	VBAR2D_DATA_MATRIX_ECC010,
	VBAR2D_DATA_MATRIX_ECC040,
	VBAR2D_DATA_MATRIX_ECC050,
	VBAR2D_DATA_MATRIX_ECC060,
	VBAR2D_DATA_MATRIX_ECC070,
	VBAR2D_DATA_MATRIX_ECC080,
	VBAR2D_DATA_MATRIX_ECC090,
	VBAR2D_DATA_MATRIX_ECC100,
	VBAR2D_DATA_MATRIX_ECC110,
	VBAR2D_DATA_MATRIX_ECC120,
	VBAR2D_DATA_MATRIX_ECC130,
	VBAR2D_DATA_MATRIX_ECC140,
	VBAR2D_DATA_MATRIX_ECC200 = 26,
};


// ========================================================================
//                      Additional VpeOpenDoc() Flag Parameters:
// ========================================================================


// ========================================================================
//                              Prototypes:
// ========================================================================
#ifdef __cplusplus
extern "C"
{
#endif

//{{DLLIMPORT("vpei3240.dll")

   void EXPO VpeSetViewable(VpeHandle hDoc, int yes_no);
   void EXPO VpeSetPrintable(VpeHandle hDoc, int yes_no);
   void EXPO VpeSetStreamable(VpeHandle hDoc, int yes_no);
   void EXPO VpeSetShadowed(VpeHandle hDoc, int yes_no);
   VpeCoord EXPO VpeWriteRTF(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR s);
   VpeCoord EXPO VpeWriteBoxRTF(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR s);
   VpeCoord EXPO VpeWriteRTFFile(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR file_name);
   VpeCoord EXPO VpeWriteBoxRTFFile(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR file_name);
   void EXPO VpeSetFirstIndent(VpeHandle hDoc, VpeCoord indent);
   void EXPO VpeSetLeftIndent(VpeHandle hDoc, VpeCoord indent);
   void EXPO VpeSetRightIndent(VpeHandle hDoc, VpeCoord indent);
   void EXPO VpeSetSpaceBefore(VpeHandle hDoc, VpeCoord space);
   void EXPO VpeSetSpaceAfter(VpeHandle hDoc, VpeCoord space);
   void EXPO VpeSetSpaceBetween(VpeHandle hDoc, VpeCoord space);
   void EXPO VpeSetDefaultTabSize(VpeHandle hDoc, VpeCoord default_tab_size);
   void EXPO VpeSetTab(VpeHandle hDoc, VpeCoord tab_position, int reserved);
   void EXPO VpeClearTab(VpeHandle hDoc, VpeCoord tab_position);
   void EXPO VpeClearAllTabs(VpeHandle hDoc);
   void EXPO VpeSetKeepLines(VpeHandle hDoc, int yes_no);
   void EXPO VpeSetKeepNextParagraph(VpeHandle hDoc, int yes_no);
   void EXPO VpeSetParagraphControl(VpeHandle hDoc, int yes_no);
   void EXPO VpeResetParagraph(VpeHandle hDoc);
   void EXPO VpeSetRTFFont(VpeHandle hDoc, int ID, LPCTSTR name);
   void EXPO VpeSetRTFColor(VpeHandle hDoc, int ID, COLORREF color);

   int EXPO VpeRenderRTF(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR s);
   int EXPO VpeRenderBoxRTF(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR s);
   int EXPO VpeRenderRTFFile(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR s);
   int EXPO VpeRenderBoxRTFFile(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR s);

   void EXPO VpeSetCharPlacement(VpeHandle hDoc, VpeCoord distance);

   VpeHandle EXPO VpeChartDataCreate(VpeHandle hDoc, int columns, int rows);
   void EXPO VpeChartDataAddRow(VpeHandle hDoc, VpeHandle hChartData);
   void EXPO VpeChartDataAddColumn(VpeHandle hDoc, VpeHandle hChartData);
   void EXPO VpeChartDataAddValue(VpeHandle hDoc, VpeHandle hChartData, int column, double value);
   void EXPO VpeChartDataAddGap(VpeHandle hDoc, VpeHandle hChartData, int column);
   void EXPO VpeChartDataAddLegend(VpeHandle hDoc, VpeHandle hChartData, LPCTSTR legend);
   void EXPO VpeChartDataAddXLabel(VpeHandle hDoc, VpeHandle hChartData, LPCTSTR xlabel);
   void EXPO VpeChartDataAddYLabel(VpeHandle hDoc, VpeHandle hChartData, LPCTSTR ylabel);
   
   void EXPO VpeChartDataSetXAxisTitle(VpeHandle hDoc, VpeHandle hChartData, LPCTSTR x_axis_title);
   void EXPO VpeChartDataSetYAxisTitle(VpeHandle hDoc, VpeHandle hChartData, LPCTSTR y_axis_title);
   
   void EXPO VpeChartDataSetColor(VpeHandle hDoc, VpeHandle hChartData, int column, COLORREF color);
   void EXPO VpeChartDataSetLineStyle(VpeHandle hDoc, VpeHandle hChartData, int column, int pen_style);
   void EXPO VpeChartDataSetHatchStyle(VpeHandle hDoc, VpeHandle hChartData, int column, int style);
   void EXPO VpeChartDataSetPointType(VpeHandle hDoc, VpeHandle hChartData, int column, int pointtype);
   void EXPO VpeChartDataSetMaximum(VpeHandle hDoc, VpeHandle hChartData, double maximum);
   void EXPO VpeChartDataSetMinimum(VpeHandle hDoc, VpeHandle hChartData, double minimum);

   void EXPO VpeSetChartTitle(VpeHandle hDoc, LPCTSTR title);
   void EXPO VpeSetChartSubTitle(VpeHandle hDoc, LPCTSTR subtitle);
   void EXPO VpeSetChartFootNote(VpeHandle hDoc, LPCTSTR footnote);
   void EXPO VpeSetChartRow(VpeHandle hDoc, int row);
   void EXPO VpeSetChartGridBkgColor(VpeHandle hDoc, COLORREF bkgcolor);
   void EXPO VpeSetChartGridBkgMode(VpeHandle hDoc, int mode);
   void EXPO VpeSetChartGridType(VpeHandle hDoc, int gridtype);
   void EXPO VpeSetChartGridColor(VpeHandle hDoc, COLORREF gridcolor);
   void EXPO VpeSetChartYGridStep(VpeHandle hDoc, double gridstepy);
   void EXPO VpeSetChartYAutoGridStep(VpeHandle hDoc);
   void EXPO VpeSetChartLegendPosition(VpeHandle hDoc, int legendpos);
   void EXPO VpeSetChartLegendBorderStat(VpeHandle hDoc, int legendborderstat);
   void EXPO VpeSetChartXLabelState(VpeHandle hDoc, int xlabelstate);
   void EXPO VpeSetChartXLabelAngle(VpeHandle hDoc, int xlabelangle);
   void EXPO VpeSetChartXLabelStartValue(VpeHandle hDoc, int xlabelstartvalue);
   void EXPO VpeSetChartYLabelState(VpeHandle hDoc, int ylabelstate);
   void EXPO VpeSetChartYLabelStep(VpeHandle hDoc, int ylabelstep);
   void EXPO VpeSetChartYLabelDivisor(VpeHandle hDoc, double ylabeldivisor);
   void EXPO VpeSetChartGridRotation(VpeHandle hDoc, int axisangle);
   void EXPO VpeSetChartYAxisAngle(VpeHandle hDoc, int angleyzaxis);
   void EXPO VpeSetChartXAxisAngle(VpeHandle hDoc, int anglexzaxis);
   void EXPO VpeChart(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, VpeHandle hChartData, int chart_type);

   void EXPO VpeSetChartBarWidthFactor(VpeHandle hDoc, double factor);
   void EXPO VpeSetChartLineWidthFactor(VpeHandle hDoc, double factor);
   void EXPO VpeSetChartLegendFontSizeFactor(VpeHandle hDoc, double factor);
   void EXPO VpeSetChartXLabelFontSizeFactor(VpeHandle hDoc, double factor);
   void EXPO VpeSetChartYLabelFontSizeFactor(VpeHandle hDoc, double factor);
   void EXPO VpeSetChartTitleFontSizeFactor(VpeHandle hDoc, double factor);
   void EXPO VpeSetChartSubTitleFontSizeFactor(VpeHandle hDoc, double factor);
   void EXPO VpeSetChartFootNoteFontSizeFactor(VpeHandle hDoc, double factor);
   void EXPO VpeSetChartAxisTitleFontSizeFactor(VpeHandle hDoc, double factor);
   void EXPO VpeSetChartPieLegendWithPercent(VpeHandle hDoc, int yes_no);
   void EXPO VpeSetChartPieLabelType(VpeHandle hDoc, int label_type);

   void EXPO VpeSetEditProtection(VpeHandle hDoc, int reserved);
   int  EXPO VpeGetEditProtection(VpeHandle hDoc);
   int  EXPO VpeGetViewable(VpeHandle hDoc);
   int  EXPO VpeGetPrintable(VpeHandle hDoc);
   int  EXPO VpeGetStreamable(VpeHandle hDoc);
   int  EXPO VpeGetShadowed(VpeHandle hDoc);

   void EXPO VpeSetExportNonPrintableObjects(VpeHandle hDoc, int yes_no);
   int  EXPO VpeGetExportNonPrintableObjects(VpeHandle hDoc);

   void EXPO VpeSetBar2DAlignment(VpeHandle hDoc, int alignment);
   int  EXPO VpeGetBar2DAlignment(VpeHandle hDoc);
   void EXPO VpeSetDataMatrixEncodingFormat(VpeHandle hDoc, int format);
   int  EXPO VpeGetDataMatrixEncodingFormat(VpeHandle hDoc);
   void EXPO VpeSetDataMatrixEccType(VpeHandle hDoc, int ecc_type);
   int  EXPO VpeGetDataMatrixEccType(VpeHandle hDoc);
   void EXPO VpeSetDataMatrixRows(VpeHandle hDoc, int rows);
   int  EXPO VpeGetDataMatrixRows(VpeHandle hDoc);
   void EXPO VpeSetDataMatrixColumns(VpeHandle hDoc, int columns);
   int  EXPO VpeGetDataMatrixColumns(VpeHandle hDoc);
   void EXPO VpeSetDataMatrixMirror(VpeHandle hDoc, int mirror);
   int  EXPO VpeGetDataMatrixMirror(VpeHandle hDoc);
   void EXPO VpeSetDataMatrixBorder(VpeHandle hDoc, int border);
   int  EXPO VpeGetDataMatrixBorder(VpeHandle hDoc);
   void EXPO VpeDataMatrix(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR lpszText);
   void EXPO VpeRenderDataMatrix(VpeHandle hDoc, LPCTSTR lpszText, VpeCoord nWidth, VpeCoord nHeight, VpeCoord nModuleWidth);
   void EXPO VpeMaxiCode(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR lpszText);
   void EXPO VpeRenderMaxiCode(VpeHandle hDoc, LPCTSTR lpszText);
   void EXPO VpeMaxiCodeEx(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, int nMode, LPCTSTR lpszZip, int nCountryCode, int nServiceClass, LPCTSTR lpszMessage, int nSymbolNumber, int nSymbolCount);
   void EXPO VpeRenderMaxiCodeEx(VpeHandle hDoc, int nMode, LPCTSTR lpszZip, int nCountryCode, int nServiceClass, LPCTSTR lpszMessage, int nSymbolNumber, int nSymbolCount);
   void EXPO VpeSetPDF417ErrorLevel(VpeHandle hDoc, int level);
   int  EXPO VpeGetPDF417ErrorLevel(VpeHandle hDoc);
   void EXPO VpeSetPDF417Rows(VpeHandle hDoc, int rows);
   int  EXPO VpeGetPDF417Rows(VpeHandle hDoc);
   void EXPO VpeSetPDF417Columns(VpeHandle hDoc, int columns);
   int  EXPO VpeGetPDF417Columns(VpeHandle hDoc);
   void EXPO VpePDF417(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR lpszText);
   void EXPO VpeRenderPDF417(VpeHandle hDoc, LPCTSTR lpszText, VpeCoord nWidth, VpeCoord nHeight, VpeCoord nModuleWidth);
   void EXPO VpeSetAztecFlags(VpeHandle hDoc, int flags);
   int  EXPO VpeGetAztecFlags(VpeHandle hDoc);
   void EXPO VpeSetAztecControl(VpeHandle hDoc, int control);
   int  EXPO VpeGetAztecControl(VpeHandle hDoc);
   void EXPO VpeSetAztecMenu(VpeHandle hDoc, int yes_no);
   int  EXPO VpeGetAztecMenu(VpeHandle hDoc);
   void EXPO VpeSetAztecMultipleSymbols(VpeHandle hDoc, int count);
   int  EXPO VpeGetAztecMultipleSymbols(VpeHandle hDoc);
   void EXPO VpeSetAztecID(VpeHandle hDoc, LPCTSTR id);
   void EXPO VpeAztec(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR lpszText);
   void EXPO VpeRenderAztec(VpeHandle hDoc, LPCTSTR lpszText, VpeCoord nWidth, VpeCoord nHeight, VpeCoord nModuleWidth);

   void EXPO VpeSetPictureScale2Gray(VpeHandle hDoc, int on_off);
   int  EXPO VpeGetPictureScale2Gray(VpeHandle hDoc);
   void EXPO VpeSetPictureScale2GrayFloat(VpeHandle hDoc, int on_off);
   int  EXPO VpeGetPictureScale2GrayFloat(VpeHandle hDoc);

   VpeHandle EXPO VpeCreateMemoryStream(VpeHandle hDoc, long chunk_size);
   long EXPO VpeStreamRead(VpeHandle hStream, BYTE *buffer, long size);
   long EXPO VpeStreamWrite(VpeHandle hStream, BYTE *buffer, long size);
   long EXPO VpeGetStreamSize(VpeHandle hStream);
   int  EXPO VpeStreamIsEof(VpeHandle hStream);
   int  EXPO VpeGetStreamState(VpeHandle hStream);
   long EXPO VpeGetStreamPosition(VpeHandle hStream);
   void EXPO VpeStreamSeek(VpeHandle hStream, long pos);
   void EXPO VpeStreamSeekEnd(VpeHandle hStream, long pos);
   void EXPO VpeStreamSeekRel(VpeHandle hStream, long offset);
   void EXPO VpeCloseStream(VpeHandle hStream);

   VpeCoord EXPO VpeWriteRTFStream(VpeHandle hDoc, VpeHandle hStream, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2);
   VpeCoord EXPO VpeWriteBoxRTFStream(VpeHandle hDoc, VpeHandle hStream, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2);
   int EXPO VpeRenderRTFStream(VpeHandle hDoc, VpeHandle hStream, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2);
   int EXPO VpeRenderBoxRTFStream(VpeHandle hDoc, VpeHandle hStream, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2);
   VpeCoord EXPO VpePictureStream(VpeHandle hDoc, VpeHandle hStream, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, LPCTSTR identifier);
   void EXPO VpeRenderPictureStream(VpeHandle hDoc, VpeHandle hStream, VpeCoord width, VpeCoord height, LPCTSTR identifier);
   long EXPO VpeGetPicturePageCountStream(VpeHandle hDoc, VpeHandle hStream);
   int  EXPO VpeWriteDocStream(VpeHandle hDoc, VpeHandle hStream);
   int  EXPO VpeWriteDocStreamPageRange(VpeHandle hDoc, VpeHandle hStream, int from_page, int to_page);
   int  EXPO VpeWriteDocPageRange(VpeHandle hDoc, LPCTSTR file_name, int from_page, int to_page);
   int  EXPO VpeReadDocStream(VpeHandle hDoc, VpeHandle hStream);
   int  EXPO VpeReadDocStreamPageRange(VpeHandle hDoc, VpeHandle hStream, int from_page, int to_page);
   int  EXPO VpeReadDocPageRange(VpeHandle hDoc, LPCTSTR file_name, int from_page, int to_page);

   void EXPO VpeSetHtmlScale(VpeHandle hDoc, double scale);
   double EXPO VpeGetHtmlScale(VpeHandle hDoc);
   void EXPO VpeSetHtmlWordSpacing(VpeHandle hDoc, double word_spacing);
   double EXPO VpeGetHtmlWordSpacing(VpeHandle hDoc);
   void EXPO VpeSetHtmlRtfLineSpacing(VpeHandle hDoc, int yes_no);
   int  EXPO VpeGetHtmlRtfLineSpacing(VpeHandle hDoc);
   void EXPO VpeSetHtmlCopyImages(VpeHandle hDoc, int yes_no);
   int  EXPO VpeGetHtmlCopyImages(VpeHandle hDoc);
   void EXPO VpeSetHtmlPageBorders(VpeHandle hDoc, int yes_no);
   int  EXPO VpeGetHtmlPageBorders(VpeHandle hDoc);
   void EXPO VpeSetHtmlPageSeparators(VpeHandle hDoc, int yes_no);
   int  EXPO VpeGetHtmlPageSeparators(VpeHandle hDoc);

   void EXPO VpeClearPage(VpeHandle hDoc);
   void EXPO VpeRemovePage(VpeHandle hDoc);
   void EXPO VpeInsertPage(VpeHandle hDoc);

#ifdef WINAPI		//defined in windows.h
   // Windows only
   void EXPO VpeSetJpegExportOptions(VpeHandle hDoc, long options);
   long EXPO VpeGetJpegExportOptions(VpeHandle hDoc);
   void EXPO VpeSetTiffExportOptions(VpeHandle hDoc, long options);
   long EXPO VpeGetTiffExportOptions(VpeHandle hDoc);
   void EXPO VpeSetGifExportOptions(VpeHandle hDoc, long options);
   long EXPO VpeGetGifExportOptions(VpeHandle hDoc);
   void EXPO VpeSetBmpExportOptions(VpeHandle hDoc, long options);
   long EXPO VpeGetBmpExportOptions(VpeHandle hDoc);
   void EXPO VpeSetPnmExportOptions(VpeHandle hDoc, long options);
   long EXPO VpeGetPnmExportOptions(VpeHandle hDoc);
   void EXPO VpeSetPictureExportColorDepth(VpeHandle hDoc, int depth);
   void EXPO VpeSetPictureExportDither(VpeHandle hDoc, int dither);
   int  EXPO VpePictureExportPage(VpeHandle hDoc, LPCTSTR file_name, int page_no);
   int  EXPO VpePictureExport(VpeHandle hDoc, LPCTSTR file_name, int page_no, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2);
   int  EXPO VpePictureExportPageStream(VpeHandle hDoc, VpeHandle hStream, int page_no);
   int  EXPO VpePictureExportStream(VpeHandle hDoc, VpeHandle hStream, int page_no, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2);

   void EXPO VpeEnableClickEvents(VpeHandle hDoc, int yes_no);
   void EXPO VpeSetObjectID(VpeHandle hDoc, int id);
   int  EXPO VpeGetObjectID(VpeHandle hDoc);

   void EXPO VpeCreateUDO(VpeHandle hDoc, VpeCoord x, VpeCoord y, VpeCoord x2, VpeCoord y2, int lParam);
   int  EXPO VpeGetUDOlParam(VpeHandle hDoc);
   HDC  EXPO VpeGetUDODC(VpeHandle hDoc);
   void EXPO VpeGetUDODrawRect(VpeHandle hDoc, RECT *rc);
   int  EXPO VpeGetUDOIsPrinting(VpeHandle hDoc);
   int  EXPO VpeGetUDOIsExporting(VpeHandle hDoc);
   int  EXPO VpeGetUDODpiX(VpeHandle hDoc);
   int  EXPO VpeGetUDODpiY(VpeHandle hDoc);

   void EXPO VpeSetPrintScale(VpeHandle hDoc, double scale);
   double EXPO VpeGetPrintScale(VpeHandle hDoc);
#endif	// WINAPI

//}}DLLIMPORT

#ifdef __cplusplus
}
#endif

#endif          // _MODULE_VPPIFACE

